# Composition

The root objects for video generation. A `Composition` owns the resolution,
frame rate, duration, and all tracks. `Track` holds clips in z-order.

## Composition

::: pymotion.composition.Composition

## Track

::: pymotion.composition.Track
